ComparatorOp

Enum ComparatorOp 

pub enum ComparatorOp {
    Exact,
    Greater,
    GreaterEq,
    Less,
    LessEq,
    Tilde,
    Caret,
}
ComparatorOp is just a re-implementation of semver::Op.

This could be removed, and a Strategy for semver::Op probably could be defined with some kind of reasonable fmt::Display ().

Variants



Exact



Greater



GreaterEq



Less



LessEq



Tilde



Caret